==> zio-aws-securityhub_2.13-5.17.128.1-sources.jar: zio/aws/securityhub/model/AwsEcsServicePlacementConstraintsDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsEcsServicePlacementConstraintsDetails(
    expression: Option[NonEmptyString] = None,
    `type`: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails = {
    import AwsEcsServicePlacementConstraintsDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
      .builder()
      .optionallyWith(
        expression.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.expression)
      .optionallyWith(
        `type`.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.`type`)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails
      .wrap(buildAwsValue())
}
object AwsEcsServicePlacementConstraintsDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails =
      zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails(
        expression.map(value => value),
        `type`.map(value => value)
      )
    def expression: Option[NonEmptyString]
    def `type`: Option[NonEmptyString]
    def getExpression: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("expression", expression)
    def getType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
  ) extends zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails.ReadOnly {
    override val expression: Option[NonEmptyString] = scala
      .Option(impl.expression())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val `type`: Option[NonEmptyString] = scala
      .Option(impl.`type`())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
  ): zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.164.1-sources.jar: zio/aws/securityhub/model/AwsEcsServicePlacementConstraintsDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsEcsServicePlacementConstraintsDetails(
    expression: Optional[NonEmptyString] = Optional.Absent,
    `type`: Optional[NonEmptyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails = {
    import AwsEcsServicePlacementConstraintsDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
      .builder()
      .optionallyWith(
        expression.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.expression)
      .optionallyWith(
        `type`.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.`type`)
      .build()
  }
  def asReadOnly
      : zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails.ReadOnly =
    zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails
      .wrap(buildAwsValue())
}
object AwsEcsServicePlacementConstraintsDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails =
      zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails(
        expression.map(value => value),
        `type`.map(value => value)
      )
    def expression: Optional[NonEmptyString]
    def `type`: Optional[NonEmptyString]
    def getExpression: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("expression", expression)
    def getType: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
  ) extends zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails.ReadOnly {
    override val expression: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.expression())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val `type`: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsEcsServicePlacementConstraintsDetails
  ): zio.aws.securityhub.model.AwsEcsServicePlacementConstraintsDetails.ReadOnly =
    new Wrapper(impl)
}
